@@ -1,7 +1,7 @@
 /*!
  * PukiWiki Advance - Yet another WikiWikiWeb clone.
  * Pukiwiki skin script for jQuery
- * Copyright (c)2010-2013 PukiWiki Advance Developer Team
+ * Copyright (c)2010-2015 PukiWiki Advance Developer Team
  *			  2010	  Logue <http://logue.be/> All rights reserved.
  *
  * This program is free software: you can redistribute it and/or modify
@@ -59,19 +59,7 @@ $.fn.bsbutton = bootstrapButton;
 		var D1 = new Date();
 	}
 
-	// Detect IE
-	var ie = (function (){
-		var v = 3,
-		div = document.createElement('div'),
-		all = div.getElementsByTagName('i');
-		while (
-			div.innerHTML = '<!--[if gt IE ' + (++v) + ']><i></i><![endif]-->',
-			all[0]
-		){};
-		return v > 4 ? v : undefined;
-	}());
-
-	var isMobile = navigator.userAgent.match(/iphone|ipod|ipad|android/i) ? true : false;
+	var isMobile = navigator.userAgent.match(/ip[hone|od|ad]|android/i) ? true : false;
 
 	// オーバーライド用
 	var pkwkInit = [], pkwkBeforeInit = [], pkwkUnload = [], pkwkBeforeUnload = [], pkwkAjaxLoad = [];
@@ -108,9 +96,9 @@ $.fn.bsbutton = bootstrapButton;
 			if (DEBUG){
 				$('#pkwk-info ul').append(
 					'<li>JavaScript framework:' + 
-					'<a href="http://modernizr.com/">Modernizr</a>: <var>'+Modernizr._version+'</var> / ' +
-					'<a href="http://jquery.com/">jQuery</a>: <var>'+$.fn.jquery+'</var> / '+
-					'<a href="http://jqueryui.com">jQuery UI</a>: <var>'+$.ui.version+ '</var>.</li>');
+					'<a href="//modernizr.com/">Modernizr</a>: <var>'+Modernizr._version+'</var> / ' +
+					'<a href="//jquery.com/">jQuery</a>: <var>'+$.fn.jquery+'</var> / '+
+					'<a href="//jqueryui.com">jQuery UI</a>: <var>'+$.ui.version+ '</var>.</li>');
 			}
 
 			var self = this;
@@ -191,15 +179,15 @@ $.fn.bsbutton = bootstrapButton;
 				// http://b.hatena.ne.jp/guide/bbutton
 				'hatena' : {
 					use : true,
-					dom : '<a href="http://b.hatena.ne.jp/entry/" class="hatena-bookmark-button" data-hatena-bookmark-layout="standard-balloon">Hatena</a>',
-					script : 'http://b.st-hatena.com/js/bookmark_button.js'
+					dom : '<a href="//b.hatena.ne.jp/entry/" data-hatena-bookmark-layout="standard-balloon"><img src="//b.st-hatena.com/images/entry-button/button-only@2x.png" alt="このエントリーをはてなブックマークに追加" width="20" height="20" style="border: none;" /></a>',
+					script : '//b.st-hatena.com/js/bookmark_button.js'
 				},
 				// Mixi
 				// http://developer.mixi.co.jp/connect/mixi_plugin/mixi_check/spec_mixi_check/
 				'mixi' : {
 					use : false,
-					dom : '<a href="http://mixi.jp/share.pl" class="mixi-check-button" data-url="'+href+'" data-button="button-6">Mixi</a>',
-					script : 'http://static.mixi.jp/js/share.js'
+					dom : '<a href="//mixi.jp/share.pl" class="mixi-check-button" data-url="'+href+'" data-button="button-6">Mixi</a>',
+					script : '//static.mixi.jp/js/share.js'
 				},
 				// Google +1 button
 				// http://www.google.com/intl/ja/webmasters/+1/button/index.html
@@ -212,20 +200,15 @@ $.fn.bsbutton = bootstrapButton;
 				// https://twitter.com/about/resources/buttons
 				'twitter' : {
 					use : true,
-					dom : '<a href="https://twitter.com/share" class="twitter-share-button" data-lang="' + lang+'">Tweet</a>',
-					script : 'http://platform.twitter.com/widgets.js'
-				},
-				// Gree
-				// https://developer.gree.net/connect/plugins/sf
-				'gree' : {
-					use : false,
-					dom : '<iframe src="http://share.gree.jp/share?url='+encodeURIComponent(href)+'&amp;type=1&amp;height=20" scrolling="no" frameborder="0" marginwidth="0" marginheight="0" style="border:none; overflow:hidden; width:100px; height:20px;" allowTransparency="true"></iframe>'
+					dom : '<a href="//twitter.com/share" class="twitter-share-button" data-dnt="true" data-lang="' + lang+'">Tweet</a>',
+					script : '//platform.twitter.com/widgets.js'
 				},
 				// Tumblr
-				// http://www.tumblr.com/docs/ja/share_button
+				// https://www.tumblr.com/buttons
 				'tumblr' : {
 					use : false,
-					dom : '<a href="http://www.tumblr.com/share" title="Share on Tumblr" style="display:inline-block; text-indent:-9999px; overflow:hidden; width:81px; height:20px; background:url(\'http://platform.tumblr.com/v1/share_1.png\') top left no-repeat transparent;"></a>'
+					dom : '<a href="//www.tumblr.com/share" title="Share on Tumblr" style="display:inline-block; text-indent:-9999px; overflow:hidden; width:81px; height:20px; background:url(\'//platform.tumblr.com/v1/share_1.png\') top left no-repeat transparent;"></a>',
+					script: '//platform.tumblr.com/v1/share.js'
 				}
 			}, this.custom.social);
 
@@ -314,7 +297,7 @@ $.fn.bsbutton = bootstrapButton;
 
 			// MathJax
 			if ($('.mathjax-eq').length !== 0){
-				$.getScript('http://cdn.mathjax.org/mathjax/latest/MathJax.js?config=TeX-AMS_HTML', function(){
+				$.getScript('//cdn.mathjax.org/mathjax/latest/MathJax.js?config=TeX-AMS_HTML', function(){
 					MathJax.Hub.Config({
 						displayAlign: "inherit",
 						TeX: {
@@ -385,7 +368,7 @@ $.fn.bsbutton = bootstrapButton;
 				var $this = $(this),
 					href = $this.attr('href');
 
-				$this.click(function(){
+				$this.on('click', function(){
 					return false;
 				});
 
@@ -506,7 +489,7 @@ $.fn.bsbutton = bootstrapButton;
 				}
 
 				// Register a 'submit' event listener on the form to perform the AJAX POST
-				$form.find('button').click(function(e){
+				$form.find('button').off('click').on('click',function(e){
 					e.preventDefault();
 
 					if ($form.children('input[type="file"]').val() === ''){
@@ -561,7 +544,7 @@ $.fn.bsbutton = bootstrapButton;
 			dom.find('.plugin-region-title').before($button);
 			$('.plugin-region-body').hide();
 
-			$('.region-btn').click(function(){
+			$('.region-btn').off('click').on('click',function(){
 				var $this = $(this),
 					$body = $this.next().next();
 
@@ -627,7 +610,7 @@ $.fn.bsbutton = bootstrapButton;
 			// 外部リンクアイコン
 			$('.fa-external-link, .fa-external-link-square').each(function(){
 				var $this = $(this);
-				$this.click(function(){
+				$this.off('click').on('click',function(){
 					window.open($this.parent().attr('href'));
 					return false;
 				});
@@ -642,20 +625,41 @@ $.fn.bsbutton = bootstrapButton;
 
 				if (!href || $this.data('ajax') === false){
 					return;
+				}else if (href === $('link[rel="canonical"]').attr('href') && $.query.get('cmd') === 'read'){
+					// クイックリロード
+					$this.off('click').on('click', function(){
+						//
+						$.ajax({
+							dataType: 'xml',
+							url: SCRIPT,
+							data : {
+								cmd:'read',
+								page: PAGE,
+								ajax:'xml'
+							},
+							type : 'GET',
+							cache : false
+						}).done(function(data){
+							//
+						}).
+						fail(function(data,status){
+							//
+						}).
+						always(function(xml){
+							var $main = $('*[role="main"]');
+
+							$(xml).find('body').each(function(){
+								$main.html($(this).text());
+								self.init();
+							});
+						});
+						return false;
+					});
 				}else if (isExternal) {
-					$this.click(function(){
+					$this.off('click').on('click',function(){
 						if (rel.match(/noreferer/)){
 							// リファラーを消す
-							if (ie){
-								// for IE
-								var subwin = window.open('','','location=yes, menubar=yes, toolbar=yes, status=yes, resizable=yes, scrollbars=yes,'),
-									d = subwin.document;
-								d.open();
-								d.write('<meta http-equiv="refresh" content="0;url='+href+'" />');
-								d.close();
-							} else if ( !href.match(/data:text\/html;/)){
-
-								// for Safari,Chrome,Firefox
+							if ( ! href.match(/data:text\/html;/)){
 								var dataUri ='data:text/html;charset=utf-8,'+encodeURIComponent(
 									'<html><head><script type="text/javascript"><!--'+"\n"+
 									'document.write(\'<meta http-equiv="refresh" content="0;url='+href+'" />\');'+"\n"+
@@ -704,7 +708,7 @@ $.fn.bsbutton = bootstrapButton;
 						// アンカースクロールを無効化判定
 						if (disable_scrolling === false){
 							// アンカースクロール
-							$this.unbind('click').bind('click', function(){
+							$this.off('click').on('click', function(){
 								var $body;
 								if ($(window).scrollTop() === 0) {
 									// スクロールが0の時エラーになる問題をごまかす
@@ -769,7 +773,7 @@ $.fn.bsbutton = bootstrapButton;
 							}
 
 							// ダイアログ描画処理
-							$this.unbind('click').bind('click', function(){
+							$this.off('click').on('click', function(){
 								params.ajax = 'json';
 								self.ajax_dialog(params,prefix,function(){
 									if ((params.cmd == 'attach' && params.pcmd.match(/upload|info/i)) || params.cmd.match(/attachref|read|backup/i) && params.age !== ''){
@@ -810,7 +814,7 @@ $.fn.bsbutton = bootstrapButton;
 				// 「トップに戻る」ボタンにイベント割り当て
 
 				$('#back-top a')
-					.click(function(){
+					.off('click').on('click', function(){
 						$('html,body').animate({scrollTop: 0}, 1000);
 						return false;
 					})
@@ -932,7 +936,7 @@ $.fn.bsbutton = bootstrapButton;
 					'<div class="ui-widget-overlay"></div>'+
 					'<div id="loading-activity"></div>'+
 				'</div>')
-					.click(function(){
+					.off('click').on('click',function(){
 						$(this).fadeOut();
 						return false;
 					})
@@ -952,7 +956,7 @@ $.fn.bsbutton = bootstrapButton;
 					speed: 1,
 					zIndex: 9999
 				})
-				.click(function(){
+				.off('click').on('click',function(){
 					$loading.fadeOut();
 				})
 			;
@@ -1190,7 +1194,7 @@ $.fn.bsbutton = bootstrapButton;
 				}).html(emoji_widget);
 
 				// イベントの割り当て
-				$('#emoji').children('ul').children('li').click(function(){
+				$('#emoji').children('ul').children('li').off('click').on('click',function(){
 					var str = $msg.getSelection().text, v = '&('+$(this).attr('name')+');';
 
 					$msg.focus();
@@ -1227,7 +1231,7 @@ $.fn.bsbutton = bootstrapButton;
 				}).html(color_widget);
 
 				// イベントの割り当て
-				$('#color_palette').children('ul').children('li').click(function(){
+				$('#color_palette').children('ul').children('li').off('click').on('click',function(){
 					var ret, str = $msg.getSelection().text, v = $(this).attr('name');
 
 					if (str === ''){
@@ -1260,7 +1264,7 @@ $.fn.bsbutton = bootstrapButton;
 			}
 
 			// ここから、イベント割り当て
-			$('.insert').click(function(){
+			$('.insert').off('click').on('click',function(){
 				var ret = '', v = $(this).attr('name');
 
 				switch (v){
@@ -1297,7 +1301,7 @@ $.fn.bsbutton = bootstrapButton;
 				return false;
 			});
 
-			$('.replace').click(function(){
+			$('.replace').off('click').on('click', function(){
 				var ret = '', str = $msg.getSelection().text, v = $(this).attr('name');
 
 				if (str === ''){
@@ -1600,7 +1604,7 @@ $.fn.bsbutton = bootstrapButton;
 			});
 
 			// ボタンをクリックした時のイベント
-			$form.find('button').click(function(e){
+			$form.find('button').off('click').on('click',function(e){
 				e.preventDefault();
 
 				var $this = $(this),
@@ -1821,7 +1825,7 @@ $.fn.bsbutton = bootstrapButton;
 				'<h1><a href="#">'+$('#title').text()+'</a><abbr title="Table of Contents">[TOC]</abbr></h1>',
 				lis.replace(/href/g,'tabindex="1" href')
 			].join(''))
-				.click(function(){
+				.off('click').on('click',function(){
 					self._hideToc();
 				}
 			);
@@ -1832,7 +1836,7 @@ $.fn.bsbutton = bootstrapButton;
 			$(toc_bg)
 				.addClass('ui-widget-overlay')
 				.css('display','none')
-				.click(function(){
+				.off('click').on('click',function(){
 					self._hideToc();
 				}
 			);
@@ -1840,7 +1844,7 @@ $.fn.bsbutton = bootstrapButton;
 
 			this.calcObj(this.toc,300);
 
-			$('.icon-toc').click(function(elem){
+			$('.icon-toc').off('click').on('click', function(elem){
 				if ($('#'+self.toc.id).hide()){
 					self._dispToc(elem,this,false);
 				}else{
@@ -1848,7 +1852,7 @@ $.fn.bsbutton = bootstrapButton;
 				}
 			}).css('display','inline-block');
 
-			$('#' + this.toc.id + ' *').click(function(){
+			$('#' + this.toc.id + ' *').off('click').on('click', function(){
 				self._hideToc();
 			});
 
@@ -1959,7 +1963,7 @@ $.fn.bsbutton = bootstrapButton;
 					$.getScript(scripts[i]);
 				}
 				if (typeof(FACEBOOK_APPID) !== 'undefined'){
-					$.getScript('http://'+ 'connect.facebook.net/' + LANG + '/all.js', function() {
+					$.getScript('//'+ 'connect.facebook.net/' + LANG + '/all.js', function() {
 						FB.init({
 							appId: FACEBOOK_APPID,
 							status	: true, // check login status
